@@ -11,12 +11,14 @@ use YAML::Syck;
 # warn "INC: (@INC)\n";
 
 use Log::Log4perl qw(:easy);
+
 my $loginit = q{
 log4perl.rootLogger=DEBUG, Screen
 log4perl.appender.Screen=Log::Log4perl::Appender::Screen
 log4perl.appender.Screen.layout=PatternLayout
 log4perl.appender.Screen.layout.ConversionPattern=----------------------------------%n%p %M() %L:%n%m%n
 };
+
 Log::Log4perl->init(\$loginit);
 
 use File::Spec;
@@ -25,7 +27,7 @@ my $tmp = File::Spec->tmpdir();
 my $dir = File::Spec->catfile($tmp, 'A2Ctest');
 
 do {
-    DEBUG("Creating temp directory $_");
+  # DEBUG("Creating temp directory $_");
     mkdir || die "Cannot create $_: $OS_ERROR\n";
 } for grep !-d, 
     $dir, 
