@@ -1,4 +1,6 @@
 package TestApp::DBI::Dispatch;
-use base qw( Apache2::Controller::Dispatch::Simple );
+use base qw( 
+    Apache2::Controller::Dispatch::Simple 
+);
 sub dispatch_map {{ default => 'TestApp::DBI::Controller' }}
 1;
